# Changelog

All notable changes to this project will be documented in this file.

## [0.5.2] - 2024-03-21

### 🐛 Bug Fixes

- Return empty set as empty

## [0.5.1] - 2024-03-20

### 📚 Documentation

- Add docs about num_decimals config

## [0.5.0] - 2024-03-19

### 🚀 Features

- Enable rounding by num decimals

### 🐛 Bug Fixes

- Typo in name

## [0.4.0] - 2024-03-13

### 🐛 Bug Fixes

- Handle longer texts
- Add language to annotator
- Fix example

## [0.3.0] - 2024-02-23

### 🚀 Features

- Add minimal and doctests jobs

### 🐛 Bug Fixes

- Adjust names
- Make code more mergeable

## [0.2.1] - 2024-01-11

## [0.2.0] - 2024-01-11

### 📚 Documentation

- Update README.md

### ⚙️ Miscellaneous Tasks

- Remove unused stuff

## [0.1.2] - 2024-01-11

### 🧪 Testing

- Fix version

## [0.1.1] - 2024-01-11

### 🚀 Features

- Poc version
- Add configs

### 🐛 Bug Fixes

- Remove language restriction

### 🚜 Refactor

- Only use fillmaskpipeline

### ⚙️ Miscellaneous Tasks

- *(deps)* Use sparv-pipeline 5.2.0

<!-- generated by git-cliff -->
